==> fusion-engine-4.0.5.tar.gz: fusion-engine-4.0.5/README.md <==
<h1 align="center">🚀 Fusion Engine</h1>

<p align="center">
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI" src="https://img.shields.io/pypi/v/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - License" src="https://img.shields.io/pypi/l/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/fusion-engine?color=blue"></a>
<a href="https://github.com/dimkauzh/fusion-engine/graphs/contributors"><img alt="GitHub contributors" src="https://img.shields.io/github/contributors/dimkauzh/fusion-engine?color=blue"></a>
</p>


<p align="center">
  <img src="https://user-images.githubusercontent.com/106883655/233103547-5693b2a3-22b9-4b68-ac2a-7220f16d48df.png" alt="logo">
</p>


Fusion is a game engine for creating graphical applications using the Pygame library and the programming language Python. It provides a simple coding interface for creating windows,
rendering graphics, and handling user input. It is and engine to create games fast and easy!

## 🗜️ Table of Contents

- [Development](#development)
- [Website](https://fusion-engine.tech/)
- [Installation](#installation)
- [Community](#community)
- [Tutorials](<https://docs.fusion-engine.tech/>)
- [Documentation](<https://docs.fusion-engine.tech/>)
- [Wiki](<https://docs.fusion-engine.tech/>)
- [Coming features](#coming-features)
- [License](#license)
- [About](#about)

## Website

Our website is at this [link](<https://fusion-engine.tech/>)

## 💾 Installation

### Using PyPi

To install our package, run this:

```bash
  pip install fusion-engine
```

Our PyPI package is at this [link](<https://pypi.org/project/fusion-engine/>)

### Install from source/devel

if you want to install the package from source and get the latest changes then you do it like this:

```bash
 git clone https://github.com/dimkauzh/fusion-engine.git
 cd fusion-engine
 python setup.py install_local
```

### Run example

If you want to run the example, then just run this command:

```bash
 git clone https://github.com/dimkauzh/fusion-engine.git
 cd fusion-engine
 python examples/example1.py
```

For different examples, you change the number to the number of the example file

## 👥 Community

Our community is just growing, so if you want to help us with the project,
it will be very helpful!
We have a discord server at this [link](<https://discord.gg/Smg3CK4ZMc>).
Need to contact us? Just DM the Owner or CEO in discord and we will try to react as fast as possible

### ❤️ Special thanks to these people

- Zenthm (Contributing)
- XCarCedo (Contributing)
- nmsderp (Contributing)
- Techsplosion (Contributor)
- FBS_Gamer (Discord server)

And our community of course!

## Tutorials
Are you exited to start with fusion engine but you dont know where to start? Then maybe its worth looking though one of our tutorials! We tried to make them as simple as possible but still very informative. You can find them [here](<https://docs.fusion-engine.tech/>)


## 📃 Documentation And WIKI

Do you need to figure out how to use a function or just want to know what it does? Then our wiki are perfect for you! But do you want to know if there is a specific function? Then the docs are perfect for you!
See at [our websites docs/wiki section](<https://docs.fusion-engine.tech/>)

## 📯 Coming features

We are working hard to implement very basic and complex stuff so our engine becomes more rigid. To see our changelog and todo list, please go [to our docs](<https://docs.fusion-engine.tech/>)

💡 - If you have more ideas, please tell us them in our [discord group](<https://discord.gg/Smg3CK4ZMc>) or create an issue!

## License

See [Licence here](LICENCE.md)

## 🗄️ About

### ⚙️ Engine

This project began May 1, 2023. The original project began in C, but it's entirely rewritten in Python for it's big userbase and ease of use (productivity). This is actually also my EuroPython 2023 project. But after some time, the community has grown, and fusion had a lot of big releases. It was becoming a big project with a giant codebase.

### ⭐ Star History

<a href="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&Timeline">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&type=Timeline&theme=dark" />
    <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&type=Timeline" />
    <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&type=Timeline" />
  </picture>
</a>

### 🇺🇦 Ukraine

We as fusion team support Ukraine and we hope it will win. Fusion engine is dedicated to Ukraine fighting the Russian invasion.
🇺🇦 Please support Ukraine! 🇺🇦

## 🚀 About Me

A 13-year-old game developer with much passion about game development. So I made this project to grow my programming skills and just make a tool that I can use for myself or a tool for other people to help them develop games.

==> fusion-engine-4.1.0.tar.gz: fusion-engine-4.1.0/README.md <==
<p align="center">
  <img src="https://github.com/dimkauzh/fusion-engine/assets/106883655/183ab172-2c3e-49b5-ba31-7c1ad63e564a" alt="logo">
</p>

<p align="center">
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI" src="https://img.shields.io/pypi/v/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - License" src="https://img.shields.io/pypi/l/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/fusion-engine?color=blue"></a>
<a href="https://pypi.org/project/fusion-engine"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/fusion-engine?color=blue"></a>
<a href="https://github.com/dimkauzh/fusion-engine/graphs/contributors"><img alt="GitHub contributors" src="https://img.shields.io/github/contributors/dimkauzh/fusion-engine?color=blue"></a>
</p>


Fusion is a game engine for creating graphical applications using the Pygame library and the programming language Python. It provides a simple coding interface for creating windows,
rendering graphics, and handling user input. It is and engine to create games fast and easy!

## 🗜️ Table of Contents

- [Development](#development)
- [Website](https://fusion-engine.tech/)
- [Installation](#installation)
- [Community](#community)
- [Tutorials](<https://docs.fusion-engine.tech/>)
- [Documentation](<https://docs.fusion-engine.tech/>)
- [Wiki](<https://docs.fusion-engine.tech/>)
- [Coming features](#coming-features)
- [License](#license)
- [About](#about)

## Website

Our website is at this [link](<https://fusion-engine.tech/>)

## 💾 Installation

### Using PyPi

To install our package, run this:

```bash
  pip install fusion-engine
```

Our PyPI package is at this [link](<https://pypi.org/project/fusion-engine/>)

### Install from source/devel

if you want to install the package from source and get the latest changes then you do it like this:

```bash
 git clone https://github.com/dimkauzh/fusion-engine.git
 cd fusion-engine
 python setup.py install
```

### Run example

If you want to run the example, then just run this command:

```bash
 git clone https://github.com/dimkauzh/fusion-engine.git
 cd fusion-engine
 python examples/example1.py
```

For different examples, you change the number to the number of the example file

## 👥 Community

Our community is just growing, so if you want to help us with the project,
it will be very helpful!
We have a discord server at this [link](<https://discord.gg/Smg3CK4ZMc>).
Need to contact us? Just DM the Owner or CEO in discord and we will try to react as fast as possible

### ❤️ Special thanks to these people

- Zenthm (Contributing)
- XCarCedo (Contributing)
- nmsderp (Contributing)
- Techsplosion (Contributor)
- FBS_Gamer (Discord server)

And our community of course!

## Tutorials
Are you exited to start with fusion engine but you dont know where to start? Then maybe its worth looking though one of our tutorials! We tried to make them as simple as possible but still very informative. You can find them [here](<https://docs.fusion-engine.tech/>)


## 📃 Documentation And WIKI

Do you need to figure out how to use a function or just want to know what it does? Then our wiki are perfect for you! But do you want to know if there is a specific function? Then the docs are perfect for you!
See at [our websites docs/wiki section](<https://docs.fusion-engine.tech/>)

## 📯 Coming features

We are working hard to implement very basic and complex stuff so our engine becomes more rigid. To see our changelog and todo list, please go [to our docs](<https://docs.fusion-engine.tech/>)

💡 - If you have more ideas, please tell us them in our [discord group](<https://discord.gg/Smg3CK4ZMc>) or create an issue!

## License

See [Licence here](LICENCE.md)

## 🗄️ About

### ⚙️ Engine

This project began May 1, 2023. The original project began in C, but it's entirely rewritten in Python for it's big userbase and ease of use (productivity). This is actually also my EuroPython 2023 project. But after some time, the community has grown, and fusion had a lot of big releases. It was becoming a big project with a giant codebase.

### ⭐ Star History

<a href="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&Timeline">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&type=Timeline&theme=dark" />
    <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&type=Timeline" />
    <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=dimkauzh/fusion-engine&type=Timeline" />
  </picture>
</a>

### 🇺🇦 Ukraine

We as fusion team support Ukraine and we hope it will win. Fusion engine is dedicated to Ukraine fighting the Russian invasion.
🇺🇦 Please support Ukraine! 🇺🇦
